# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetClientConfigResult',
    'AwaitableGetClientConfigResult',
    'get_client_config',
    'get_client_config_output',
]

@pulumi.output_type
class GetClientConfigResult:
    """
    A collection of values returned by getClientConfig.
    """
    def __init__(__self__, client_id=None, id=None, object_id=None, subscription_id=None, tenant_id=None):
        if client_id and not isinstance(client_id, str):
            raise TypeError("Expected argument 'client_id' to be a str")
        pulumi.set(__self__, "client_id", client_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if object_id and not isinstance(object_id, str):
            raise TypeError("Expected argument 'object_id' to be a str")
        pulumi.set(__self__, "object_id", object_id)
        if subscription_id and not isinstance(subscription_id, str):
            raise TypeError("Expected argument 'subscription_id' to be a str")
        pulumi.set(__self__, "subscription_id", subscription_id)
        if tenant_id and not isinstance(tenant_id, str):
            raise TypeError("Expected argument 'tenant_id' to be a str")
        pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter(name="clientId")
    def client_id(self) -> builtins.str:
        """
        is set to the Azure Client ID (Application Object ID).
        """
        return pulumi.get(self, "client_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="objectId")
    def object_id(self) -> builtins.str:
        """
        is set to the Azure Object ID.
        """
        return pulumi.get(self, "object_id")

    @property
    @pulumi.getter(name="subscriptionId")
    def subscription_id(self) -> builtins.str:
        """
        is set to the Azure Subscription ID.
        """
        return pulumi.get(self, "subscription_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> builtins.str:
        """
        is set to the Azure Tenant ID.
        """
        return pulumi.get(self, "tenant_id")


class AwaitableGetClientConfigResult(GetClientConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClientConfigResult(
            client_id=self.client_id,
            id=self.id,
            object_id=self.object_id,
            subscription_id=self.subscription_id,
            tenant_id=self.tenant_id)


def get_client_config(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClientConfigResult:
    """
    Use this data source to access the configuration of the AzureRM provider.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    current = azure.core.get_client_config()
    pulumi.export("accountId", current.client_id)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:core/getClientConfig:getClientConfig', __args__, opts=opts, typ=GetClientConfigResult).value

    return AwaitableGetClientConfigResult(
        client_id=pulumi.get(__ret__, 'client_id'),
        id=pulumi.get(__ret__, 'id'),
        object_id=pulumi.get(__ret__, 'object_id'),
        subscription_id=pulumi.get(__ret__, 'subscription_id'),
        tenant_id=pulumi.get(__ret__, 'tenant_id'))
def get_client_config_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetClientConfigResult]:
    """
    Use this data source to access the configuration of the AzureRM provider.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    current = azure.core.get_client_config()
    pulumi.export("accountId", current.client_id)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:core/getClientConfig:getClientConfig', __args__, opts=opts, typ=GetClientConfigResult)
    return __ret__.apply(lambda __response__: GetClientConfigResult(
        client_id=pulumi.get(__response__, 'client_id'),
        id=pulumi.get(__response__, 'id'),
        object_id=pulumi.get(__response__, 'object_id'),
        subscription_id=pulumi.get(__response__, 'subscription_id'),
        tenant_id=pulumi.get(__response__, 'tenant_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'VirtualMachineManagerVirtualMachineInstanceHardware',
    'VirtualMachineManagerVirtualMachineInstanceInfrastructure',
    'VirtualMachineManagerVirtualMachineInstanceNetworkInterface',
    'VirtualMachineManagerVirtualMachineInstanceOperatingSystem',
    'VirtualMachineManagerVirtualMachineInstanceStorageDisk',
    'GetVirtualMachineManagerInventoryItemsInventoryItemResult',
]

@pulumi.output_type
class VirtualMachineManagerVirtualMachineInstanceHardware(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cpuCount":
            suggest = "cpu_count"
        elif key == "dynamicMemoryMaxInMb":
            suggest = "dynamic_memory_max_in_mb"
        elif key == "dynamicMemoryMinInMb":
            suggest = "dynamic_memory_min_in_mb"
        elif key == "limitCpuForMigrationEnabled":
            suggest = "limit_cpu_for_migration_enabled"
        elif key == "memoryInMb":
            suggest = "memory_in_mb"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VirtualMachineManagerVirtualMachineInstanceHardware. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VirtualMachineManagerVirtualMachineInstanceHardware.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VirtualMachineManagerVirtualMachineInstanceHardware.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cpu_count: Optional[builtins.int] = None,
                 dynamic_memory_max_in_mb: Optional[builtins.int] = None,
                 dynamic_memory_min_in_mb: Optional[builtins.int] = None,
                 limit_cpu_for_migration_enabled: Optional[builtins.bool] = None,
                 memory_in_mb: Optional[builtins.int] = None):
        """
        :param builtins.int cpu_count: The number of vCPUs for the Virtual Machine. Possible values are between `1` and `64`.
        :param builtins.int dynamic_memory_max_in_mb: The max dynamic memory for the Virtual Machine. Possible values are between `32` and `1048576`.
        :param builtins.int dynamic_memory_min_in_mb: The min dynamic memory for the Virtual Machine. Possible values are between `32` and `1048576`.
        :param builtins.bool limit_cpu_for_migration_enabled: Whether processor compatibility mode for live migration of Virtual Machines is enabled.
        :param builtins.int memory_in_mb: The size of a Virtual Machine's memory. Possible values are between `32` and `1048576`.
        """
        if cpu_count is not None:
            pulumi.set(__self__, "cpu_count", cpu_count)
        if dynamic_memory_max_in_mb is not None:
            pulumi.set(__self__, "dynamic_memory_max_in_mb", dynamic_memory_max_in_mb)
        if dynamic_memory_min_in_mb is not None:
            pulumi.set(__self__, "dynamic_memory_min_in_mb", dynamic_memory_min_in_mb)
        if limit_cpu_for_migration_enabled is not None:
            pulumi.set(__self__, "limit_cpu_for_migration_enabled", limit_cpu_for_migration_enabled)
        if memory_in_mb is not None:
            pulumi.set(__self__, "memory_in_mb", memory_in_mb)

    @property
    @pulumi.getter(name="cpuCount")
    def cpu_count(self) -> Optional[builtins.int]:
        """
        The number of vCPUs for the Virtual Machine. Possible values are between `1` and `64`.
        """
        return pulumi.get(self, "cpu_count")

    @property
    @pulumi.getter(name="dynamicMemoryMaxInMb")
    def dynamic_memory_max_in_mb(self) -> Optional[builtins.int]:
        """
        The max dynamic memory for the Virtual Machine. Possible values are between `32` and `1048576`.
        """
        return pulumi.get(self, "dynamic_memory_max_in_mb")

    @property
    @pulumi.getter(name="dynamicMemoryMinInMb")
    def dynamic_memory_min_in_mb(self) -> Optional[builtins.int]:
        """
        The min dynamic memory for the Virtual Machine. Possible values are between `32` and `1048576`.
        """
        return pulumi.get(self, "dynamic_memory_min_in_mb")

    @property
    @pulumi.getter(name="limitCpuForMigrationEnabled")
    def limit_cpu_for_migration_enabled(self) -> Optional[builtins.bool]:
        """
        Whether processor compatibility mode for live migration of Virtual Machines is enabled.
        """
        return pulumi.get(self, "limit_cpu_for_migration_enabled")

    @property
    @pulumi.getter(name="memoryInMb")
    def memory_in_mb(self) -> Optional[builtins.int]:
        """
        The size of a Virtual Machine's memory. Possible values are between `32` and `1048576`.
        """
        return pulumi.get(self, "memory_in_mb")


@pulumi.output_type
class VirtualMachineManagerVirtualMachineInstanceInfrastructure(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "checkpointType":
            suggest = "checkpoint_type"
        elif key == "systemCenterVirtualMachineManagerCloudId":
            suggest = "system_center_virtual_machine_manager_cloud_id"
        elif key == "systemCenterVirtualMachineManagerInventoryItemId":
            suggest = "system_center_virtual_machine_manager_inventory_item_id"
        elif key == "systemCenterVirtualMachineManagerTemplateId":
            suggest = "system_center_virtual_machine_manager_template_id"
        elif key == "systemCenterVirtualMachineManagerVirtualMachineServerId":
            suggest = "system_center_virtual_machine_manager_virtual_machine_server_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VirtualMachineManagerVirtualMachineInstanceInfrastructure. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VirtualMachineManagerVirtualMachineInstanceInfrastructure.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VirtualMachineManagerVirtualMachineInstanceInfrastructure.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 checkpoint_type: Optional[builtins.str] = None,
                 system_center_virtual_machine_manager_cloud_id: Optional[builtins.str] = None,
                 system_center_virtual_machine_manager_inventory_item_id: Optional[builtins.str] = None,
                 system_center_virtual_machine_manager_template_id: Optional[builtins.str] = None,
                 system_center_virtual_machine_manager_virtual_machine_server_id: Optional[builtins.str] = None):
        """
        :param builtins.str checkpoint_type: The type of checkpoint supported for the Virtual Machine. Possible values are `Disabled`, `Production`, `ProductionOnly` and `Standard`.
        :param builtins.str system_center_virtual_machine_manager_cloud_id: The ID of the System Center Virtual Machine Manager Cloud resource to use for deploying the Virtual Machine. Changing this forces a new resource to be created.
        :param builtins.str system_center_virtual_machine_manager_inventory_item_id: The ID of the System Center Virtual Machine Manager Inventory Item for System Center Virtual Machine Manager Virtual Machine Instance. Changing this forces a new resource to be created.
        :param builtins.str system_center_virtual_machine_manager_template_id: The ID of the System Center Virtual Machine Manager Virtual Machine Template to use for deploying the Virtual Machine. Changing this forces a new resource to be created.
        :param builtins.str system_center_virtual_machine_manager_virtual_machine_server_id: The ID of the System Center Virtual Machine Manager Virtual Machine. Changing this forces a new resource to be created.
        """
        if checkpoint_type is not None:
            pulumi.set(__self__, "checkpoint_type", checkpoint_type)
        if system_center_virtual_machine_manager_cloud_id is not None:
            pulumi.set(__self__, "system_center_virtual_machine_manager_cloud_id", system_center_virtual_machine_manager_cloud_id)
        if system_center_virtual_machine_manager_inventory_item_id is not None:
            pulumi.set(__self__, "system_center_virtual_machine_manager_inventory_item_id", system_center_virtual_machine_manager_inventory_item_id)
        if system_center_virtual_machine_manager_template_id is not None:
            pulumi.set(__self__, "system_center_virtual_machine_manager_template_id", system_center_virtual_machine_manager_template_id)
        if system_center_virtual_machine_manager_virtual_machine_server_id is not None:
            pulumi.set(__self__, "system_center_virtual_machine_manager_virtual_machine_server_id", system_center_virtual_machine_manager_virtual_machine_server_id)

    @property
    @pulumi.getter(name="checkpointType")
    def checkpoint_type(self) -> Optional[builtins.str]:
        """
        The type of checkpoint supported for the Virtual Machine. Possible values are `Disabled`, `Production`, `ProductionOnly` and `Standard`.
        """
        return pulumi.get(self, "checkpoint_type")

    @property
    @pulumi.getter(name="systemCenterVirtualMachineManagerCloudId")
    def system_center_virtual_machine_manager_cloud_id(self) -> Optional[builtins.str]:
        """
        The ID of the System Center Virtual Machine Manager Cloud resource to use for deploying the Virtual Machine. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "system_center_virtual_machine_manager_cloud_id")

    @property
    @pulumi.getter(name="systemCenterVirtualMachineManagerInventoryItemId")
    def system_center_virtual_machine_manager_inventory_item_id(self) -> Optional[builtins.str]:
        """
        The ID of the System Center Virtual Machine Manager Inventory Item for System Center Virtual Machine Manager Virtual Machine Instance. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "system_center_virtual_machine_manager_inventory_item_id")

    @property
    @pulumi.getter(name="systemCenterVirtualMachineManagerTemplateId")
    def system_center_virtual_machine_manager_template_id(self) -> Optional[builtins.str]:
        """
        The ID of the System Center Virtual Machine Manager Virtual Machine Template to use for deploying the Virtual Machine. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "system_center_virtual_machine_manager_template_id")

    @property
    @pulumi.getter(name="systemCenterVirtualMachineManagerVirtualMachineServerId")
    def system_center_virtual_machine_manager_virtual_machine_server_id(self) -> Optional[builtins.str]:
        """
        The ID of the System Center Virtual Machine Manager Virtual Machine. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "system_center_virtual_machine_manager_virtual_machine_server_id")


@pulumi.output_type
class VirtualMachineManagerVirtualMachineInstanceNetworkInterface(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "ipv4AddressType":
            suggest = "ipv4_address_type"
        elif key == "ipv6AddressType":
            suggest = "ipv6_address_type"
        elif key == "macAddressType":
            suggest = "mac_address_type"
        elif key == "virtualNetworkId":
            suggest = "virtual_network_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VirtualMachineManagerVirtualMachineInstanceNetworkInterface. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VirtualMachineManagerVirtualMachineInstanceNetworkInterface.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VirtualMachineManagerVirtualMachineInstanceNetworkInterface.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 name: builtins.str,
                 ipv4_address_type: Optional[builtins.str] = None,
                 ipv6_address_type: Optional[builtins.str] = None,
                 mac_address_type: Optional[builtins.str] = None,
                 virtual_network_id: Optional[builtins.str] = None):
        """
        :param builtins.str name: The name of the Virtual Network in System Center Virtual Machine Manager Server that the Network Interface is connected to.
        :param builtins.str ipv4_address_type: The IPv4 address type. Possible values are `Dynamic` and `Static`.
        :param builtins.str ipv6_address_type: The IPv6 address type. Possible values are `Dynamic` and `Static`.
        :param builtins.str mac_address_type: The MAC address type. Possible values are `Dynamic` and `Static`.
        :param builtins.str virtual_network_id: The ID of the System Center Virtual Machine Manager Virtual Network to connect the Network Interface.
        """
        pulumi.set(__self__, "name", name)
        if ipv4_address_type is not None:
            pulumi.set(__self__, "ipv4_address_type", ipv4_address_type)
        if ipv6_address_type is not None:
            pulumi.set(__self__, "ipv6_address_type", ipv6_address_type)
        if mac_address_type is not None:
            pulumi.set(__self__, "mac_address_type", mac_address_type)
        if virtual_network_id is not None:
            pulumi.set(__self__, "virtual_network_id", virtual_network_id)

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the Virtual Network in System Center Virtual Machine Manager Server that the Network Interface is connected to.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="ipv4AddressType")
    def ipv4_address_type(self) -> Optional[builtins.str]:
        """
        The IPv4 address type. Possible values are `Dynamic` and `Static`.
        """
        return pulumi.get(self, "ipv4_address_type")

    @property
    @pulumi.getter(name="ipv6AddressType")
    def ipv6_address_type(self) -> Optional[builtins.str]:
        """
        The IPv6 address type. Possible values are `Dynamic` and `Static`.
        """
        return pulumi.get(self, "ipv6_address_type")

    @property
    @pulumi.getter(name="macAddressType")
    def mac_address_type(self) -> Optional[builtins.str]:
        """
        The MAC address type. Possible values are `Dynamic` and `Static`.
        """
        return pulumi.get(self, "mac_address_type")

    @property
    @pulumi.getter(name="virtualNetworkId")
    def virtual_network_id(self) -> Optional[builtins.str]:
        """
        The ID of the System Center Virtual Machine Manager Virtual Network to connect the Network Interface.
        """
        return pulumi.get(self, "virtual_network_id")


@pulumi.output_type
class VirtualMachineManagerVirtualMachineInstanceOperatingSystem(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "adminPassword":
            suggest = "admin_password"
        elif key == "computerName":
            suggest = "computer_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VirtualMachineManagerVirtualMachineInstanceOperatingSystem. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VirtualMachineManagerVirtualMachineInstanceOperatingSystem.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VirtualMachineManagerVirtualMachineInstanceOperatingSystem.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 admin_password: Optional[builtins.str] = None,
                 computer_name: Optional[builtins.str] = None):
        """
        :param builtins.str admin_password: The admin password of the Virtual Machine. Changing this forces a new resource to be created.
        :param builtins.str computer_name: The computer name of the Virtual Machine. Changing this forces a new resource to be created.
        """
        if admin_password is not None:
            pulumi.set(__self__, "admin_password", admin_password)
        if computer_name is not None:
            pulumi.set(__self__, "computer_name", computer_name)

    @property
    @pulumi.getter(name="adminPassword")
    def admin_password(self) -> Optional[builtins.str]:
        """
        The admin password of the Virtual Machine. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "admin_password")

    @property
    @pulumi.getter(name="computerName")
    def computer_name(self) -> Optional[builtins.str]:
        """
        The computer name of the Virtual Machine. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "computer_name")


@pulumi.output_type
class VirtualMachineManagerVirtualMachineInstanceStorageDisk(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "busType":
            suggest = "bus_type"
        elif key == "diskSizeGb":
            suggest = "disk_size_gb"
        elif key == "storageQosPolicyName":
            suggest = "storage_qos_policy_name"
        elif key == "templateDiskId":
            suggest = "template_disk_id"
        elif key == "vhdType":
            suggest = "vhd_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in VirtualMachineManagerVirtualMachineInstanceStorageDisk. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        VirtualMachineManagerVirtualMachineInstanceStorageDisk.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        VirtualMachineManagerVirtualMachineInstanceStorageDisk.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bus: Optional[builtins.int] = None,
                 bus_type: Optional[builtins.str] = None,
                 disk_size_gb: Optional[builtins.int] = None,
                 lun: Optional[builtins.int] = None,
                 name: Optional[builtins.str] = None,
                 storage_qos_policy_name: Optional[builtins.str] = None,
                 template_disk_id: Optional[builtins.str] = None,
                 vhd_type: Optional[builtins.str] = None):
        """
        :param builtins.int bus: The disk bus. Possible values are between `0` and `3`.
        :param builtins.str bus_type: The disk bus type. Possible values are `IDE` and `SCSI`.
        :param builtins.int disk_size_gb: The disk total size.
        :param builtins.int lun: The disk lun. Possible values are between `0` and `63`.
        :param builtins.str name: The name of the disk.
        :param builtins.str storage_qos_policy_name: The name of the Storage QoS policy.
        :param builtins.str template_disk_id: The disk ID in the System Center Virtual Machine Manager Virtual Machine Template. Changing this forces a new resource to be created.
        :param builtins.str vhd_type: The disk vhd type. Possible values are `Dynamic` and `Fixed`.
        """
        if bus is not None:
            pulumi.set(__self__, "bus", bus)
        if bus_type is not None:
            pulumi.set(__self__, "bus_type", bus_type)
        if disk_size_gb is not None:
            pulumi.set(__self__, "disk_size_gb", disk_size_gb)
        if lun is not None:
            pulumi.set(__self__, "lun", lun)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if storage_qos_policy_name is not None:
            pulumi.set(__self__, "storage_qos_policy_name", storage_qos_policy_name)
        if template_disk_id is not None:
            pulumi.set(__self__, "template_disk_id", template_disk_id)
        if vhd_type is not None:
            pulumi.set(__self__, "vhd_type", vhd_type)

    @property
    @pulumi.getter
    def bus(self) -> Optional[builtins.int]:
        """
        The disk bus. Possible values are between `0` and `3`.
        """
        return pulumi.get(self, "bus")

    @property
    @pulumi.getter(name="busType")
    def bus_type(self) -> Optional[builtins.str]:
        """
        The disk bus type. Possible values are `IDE` and `SCSI`.
        """
        return pulumi.get(self, "bus_type")

    @property
    @pulumi.getter(name="diskSizeGb")
    def disk_size_gb(self) -> Optional[builtins.int]:
        """
        The disk total size.
        """
        return pulumi.get(self, "disk_size_gb")

    @property
    @pulumi.getter
    def lun(self) -> Optional[builtins.int]:
        """
        The disk lun. Possible values are between `0` and `63`.
        """
        return pulumi.get(self, "lun")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        The name of the disk.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="storageQosPolicyName")
    def storage_qos_policy_name(self) -> Optional[builtins.str]:
        """
        The name of the Storage QoS policy.
        """
        return pulumi.get(self, "storage_qos_policy_name")

    @property
    @pulumi.getter(name="templateDiskId")
    def template_disk_id(self) -> Optional[builtins.str]:
        """
        The disk ID in the System Center Virtual Machine Manager Virtual Machine Template. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "template_disk_id")

    @property
    @pulumi.getter(name="vhdType")
    def vhd_type(self) -> Optional[builtins.str]:
        """
        The disk vhd type. Possible values are `Dynamic` and `Fixed`.
        """
        return pulumi.get(self, "vhd_type")


@pulumi.output_type
class GetVirtualMachineManagerInventoryItemsInventoryItemResult(dict):
    def __init__(__self__, *,
                 id: builtins.str,
                 name: builtins.str,
                 uuid: builtins.str):
        """
        :param builtins.str id: The ID of the System Center Virtual Machine Manager Inventory Item.
        :param builtins.str name: The name of the System Center Virtual Machine Manager Inventory Item.
        :param builtins.str uuid: The UUID of the System Center Virtual Machine Manager Inventory Item that is assigned by System Center Virtual Machine Manager.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "uuid", uuid)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The ID of the System Center Virtual Machine Manager Inventory Item.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        The name of the System Center Virtual Machine Manager Inventory Item.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def uuid(self) -> builtins.str:
        """
        The UUID of the System Center Virtual Machine Manager Inventory Item that is assigned by System Center Virtual Machine Manager.
        """
        return pulumi.get(self, "uuid")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BackupPolicyPostgresqlFlexibleServerArgs', 'BackupPolicyPostgresqlFlexibleServer']

@pulumi.input_type
class BackupPolicyPostgresqlFlexibleServerArgs:
    def __init__(__self__, *,
                 backup_repeating_time_intervals: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 default_retention_rule: pulumi.Input['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs'],
                 vault_id: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 retention_rules: Optional[pulumi.Input[Sequence[pulumi.Input['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs']]]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a BackupPolicyPostgresqlFlexibleServer resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] backup_repeating_time_intervals: Specifies a list of repeating time interval. It supports weekly back. It should follow `ISO 8601` repeating time interval format. Changing this forces a new resource to be created.
        :param pulumi.Input['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs'] default_retention_rule: A `default_retention_rule` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] vault_id: The ID of the Backup Vault where the Backup Policy PostgreSQL Flexible Server should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies the name of the Backup Policy for the PostgreSQL Flexible Server. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs']]] retention_rules: One or more `retention_rule` blocks as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] time_zone: Specifies the Time Zone which should be used by the backup schedule. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "backup_repeating_time_intervals", backup_repeating_time_intervals)
        pulumi.set(__self__, "default_retention_rule", default_retention_rule)
        pulumi.set(__self__, "vault_id", vault_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if retention_rules is not None:
            pulumi.set(__self__, "retention_rules", retention_rules)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)

    @property
    @pulumi.getter(name="backupRepeatingTimeIntervals")
    def backup_repeating_time_intervals(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        Specifies a list of repeating time interval. It supports weekly back. It should follow `ISO 8601` repeating time interval format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "backup_repeating_time_intervals")

    @backup_repeating_time_intervals.setter
    def backup_repeating_time_intervals(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "backup_repeating_time_intervals", value)

    @property
    @pulumi.getter(name="defaultRetentionRule")
    def default_retention_rule(self) -> pulumi.Input['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs']:
        """
        A `default_retention_rule` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "default_retention_rule")

    @default_retention_rule.setter
    def default_retention_rule(self, value: pulumi.Input['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs']):
        pulumi.set(self, "default_retention_rule", value)

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the Backup Vault where the Backup Policy PostgreSQL Flexible Server should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "vault_id")

    @vault_id.setter
    def vault_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vault_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the name of the Backup Policy for the PostgreSQL Flexible Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="retentionRules")
    def retention_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs']]]]:
        """
        One or more `retention_rule` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "retention_rules")

    @retention_rules.setter
    def retention_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs']]]]):
        pulumi.set(self, "retention_rules", value)

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the Time Zone which should be used by the backup schedule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "time_zone", value)


@pulumi.input_type
class _BackupPolicyPostgresqlFlexibleServerState:
    def __init__(__self__, *,
                 backup_repeating_time_intervals: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 default_retention_rule: Optional[pulumi.Input['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs']] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 retention_rules: Optional[pulumi.Input[Sequence[pulumi.Input['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs']]]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 vault_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering BackupPolicyPostgresqlFlexibleServer resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] backup_repeating_time_intervals: Specifies a list of repeating time interval. It supports weekly back. It should follow `ISO 8601` repeating time interval format. Changing this forces a new resource to be created.
        :param pulumi.Input['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs'] default_retention_rule: A `default_retention_rule` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies the name of the Backup Policy for the PostgreSQL Flexible Server. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs']]] retention_rules: One or more `retention_rule` blocks as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] time_zone: Specifies the Time Zone which should be used by the backup schedule. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] vault_id: The ID of the Backup Vault where the Backup Policy PostgreSQL Flexible Server should exist. Changing this forces a new resource to be created.
        """
        if backup_repeating_time_intervals is not None:
            pulumi.set(__self__, "backup_repeating_time_intervals", backup_repeating_time_intervals)
        if default_retention_rule is not None:
            pulumi.set(__self__, "default_retention_rule", default_retention_rule)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if retention_rules is not None:
            pulumi.set(__self__, "retention_rules", retention_rules)
        if time_zone is not None:
            pulumi.set(__self__, "time_zone", time_zone)
        if vault_id is not None:
            pulumi.set(__self__, "vault_id", vault_id)

    @property
    @pulumi.getter(name="backupRepeatingTimeIntervals")
    def backup_repeating_time_intervals(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Specifies a list of repeating time interval. It supports weekly back. It should follow `ISO 8601` repeating time interval format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "backup_repeating_time_intervals")

    @backup_repeating_time_intervals.setter
    def backup_repeating_time_intervals(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "backup_repeating_time_intervals", value)

    @property
    @pulumi.getter(name="defaultRetentionRule")
    def default_retention_rule(self) -> Optional[pulumi.Input['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs']]:
        """
        A `default_retention_rule` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "default_retention_rule")

    @default_retention_rule.setter
    def default_retention_rule(self, value: Optional[pulumi.Input['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs']]):
        pulumi.set(self, "default_retention_rule", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the name of the Backup Policy for the PostgreSQL Flexible Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="retentionRules")
    def retention_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs']]]]:
        """
        One or more `retention_rule` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "retention_rules")

    @retention_rules.setter
    def retention_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs']]]]):
        pulumi.set(self, "retention_rules", value)

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the Time Zone which should be used by the backup schedule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "time_zone")

    @time_zone.setter
    def time_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "time_zone", value)

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the Backup Vault where the Backup Policy PostgreSQL Flexible Server should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "vault_id")

    @vault_id.setter
    def vault_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vault_id", value)


@pulumi.type_token("azure:dataprotection/backupPolicyPostgresqlFlexibleServer:BackupPolicyPostgresqlFlexibleServer")
class BackupPolicyPostgresqlFlexibleServer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_repeating_time_intervals: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 default_retention_rule: Optional[pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 retention_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerRetentionRuleArgsDict']]]]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 vault_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages a Backup Policy to back up PostgreSQL Flexible Server.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_backup_vault = azure.dataprotection.BackupVault("example",
            name="example-backup-vault",
            resource_group_name=example.name,
            location=example.location,
            datastore_type="VaultStore",
            redundancy="LocallyRedundant",
            identity={
                "type": "SystemAssigned",
            })
        example_backup_policy_postgresql_flexible_server = azure.dataprotection.BackupPolicyPostgresqlFlexibleServer("example",
            name="example-backup-policy",
            vault_id=example_backup_vault.id,
            backup_repeating_time_intervals=["R/2021-05-23T02:30:00+00:00/P1W"],
            time_zone="India Standard Time",
            default_retention_rule={
                "life_cycles": [{
                    "duration": "P4M",
                    "data_store_type": "VaultStore",
                }],
            },
            retention_rules=[
                {
                    "name": "weekly",
                    "life_cycles": [{
                        "duration": "P6M",
                        "data_store_type": "VaultStore",
                    }],
                    "priority": 20,
                    "criteria": {
                        "absolute_criteria": "FirstOfWeek",
                    },
                },
                {
                    "name": "thursday",
                    "life_cycles": [{
                        "duration": "P1W",
                        "data_store_type": "VaultStore",
                    }],
                    "priority": 25,
                    "criteria": {
                        "days_of_weeks": ["Thursday"],
                        "scheduled_backup_times": ["2021-05-23T02:30:00Z"],
                    },
                },
                {
                    "name": "monthly",
                    "life_cycles": [{
                        "duration": "P1D",
                        "data_store_type": "VaultStore",
                    }],
                    "priority": 15,
                    "criteria": {
                        "weeks_of_months": [
                            "First",
                            "Last",
                        ],
                        "days_of_weeks": ["Tuesday"],
                        "scheduled_backup_times": ["2021-05-23T02:30:00Z"],
                    },
                },
            ])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.DataProtection`: 2024-04-01

        ## Import

        Backup Policy PostgreSQL Flexible Server's can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:dataprotection/backupPolicyPostgresqlFlexibleServer:BackupPolicyPostgresqlFlexibleServer example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DataProtection/backupVaults/vault1/backupPolicies/backupPolicy1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] backup_repeating_time_intervals: Specifies a list of repeating time interval. It supports weekly back. It should follow `ISO 8601` repeating time interval format. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgsDict']] default_retention_rule: A `default_retention_rule` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies the name of the Backup Policy for the PostgreSQL Flexible Server. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerRetentionRuleArgsDict']]]] retention_rules: One or more `retention_rule` blocks as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] time_zone: Specifies the Time Zone which should be used by the backup schedule. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] vault_id: The ID of the Backup Vault where the Backup Policy PostgreSQL Flexible Server should exist. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BackupPolicyPostgresqlFlexibleServerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Backup Policy to back up PostgreSQL Flexible Server.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_backup_vault = azure.dataprotection.BackupVault("example",
            name="example-backup-vault",
            resource_group_name=example.name,
            location=example.location,
            datastore_type="VaultStore",
            redundancy="LocallyRedundant",
            identity={
                "type": "SystemAssigned",
            })
        example_backup_policy_postgresql_flexible_server = azure.dataprotection.BackupPolicyPostgresqlFlexibleServer("example",
            name="example-backup-policy",
            vault_id=example_backup_vault.id,
            backup_repeating_time_intervals=["R/2021-05-23T02:30:00+00:00/P1W"],
            time_zone="India Standard Time",
            default_retention_rule={
                "life_cycles": [{
                    "duration": "P4M",
                    "data_store_type": "VaultStore",
                }],
            },
            retention_rules=[
                {
                    "name": "weekly",
                    "life_cycles": [{
                        "duration": "P6M",
                        "data_store_type": "VaultStore",
                    }],
                    "priority": 20,
                    "criteria": {
                        "absolute_criteria": "FirstOfWeek",
                    },
                },
                {
                    "name": "thursday",
                    "life_cycles": [{
                        "duration": "P1W",
                        "data_store_type": "VaultStore",
                    }],
                    "priority": 25,
                    "criteria": {
                        "days_of_weeks": ["Thursday"],
                        "scheduled_backup_times": ["2021-05-23T02:30:00Z"],
                    },
                },
                {
                    "name": "monthly",
                    "life_cycles": [{
                        "duration": "P1D",
                        "data_store_type": "VaultStore",
                    }],
                    "priority": 15,
                    "criteria": {
                        "weeks_of_months": [
                            "First",
                            "Last",
                        ],
                        "days_of_weeks": ["Tuesday"],
                        "scheduled_backup_times": ["2021-05-23T02:30:00Z"],
                    },
                },
            ])
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.DataProtection`: 2024-04-01

        ## Import

        Backup Policy PostgreSQL Flexible Server's can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:dataprotection/backupPolicyPostgresqlFlexibleServer:BackupPolicyPostgresqlFlexibleServer example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.DataProtection/backupVaults/vault1/backupPolicies/backupPolicy1
        ```

        :param str resource_name: The name of the resource.
        :param BackupPolicyPostgresqlFlexibleServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BackupPolicyPostgresqlFlexibleServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_repeating_time_intervals: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 default_retention_rule: Optional[pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgsDict']]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 retention_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerRetentionRuleArgsDict']]]]] = None,
                 time_zone: Optional[pulumi.Input[builtins.str]] = None,
                 vault_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BackupPolicyPostgresqlFlexibleServerArgs.__new__(BackupPolicyPostgresqlFlexibleServerArgs)

            if backup_repeating_time_intervals is None and not opts.urn:
                raise TypeError("Missing required property 'backup_repeating_time_intervals'")
            __props__.__dict__["backup_repeating_time_intervals"] = backup_repeating_time_intervals
            if default_retention_rule is None and not opts.urn:
                raise TypeError("Missing required property 'default_retention_rule'")
            __props__.__dict__["default_retention_rule"] = default_retention_rule
            __props__.__dict__["name"] = name
            __props__.__dict__["retention_rules"] = retention_rules
            __props__.__dict__["time_zone"] = time_zone
            if vault_id is None and not opts.urn:
                raise TypeError("Missing required property 'vault_id'")
            __props__.__dict__["vault_id"] = vault_id
        super(BackupPolicyPostgresqlFlexibleServer, __self__).__init__(
            'azure:dataprotection/backupPolicyPostgresqlFlexibleServer:BackupPolicyPostgresqlFlexibleServer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_repeating_time_intervals: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            default_retention_rule: Optional[pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgsDict']]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            retention_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerRetentionRuleArgsDict']]]]] = None,
            time_zone: Optional[pulumi.Input[builtins.str]] = None,
            vault_id: Optional[pulumi.Input[builtins.str]] = None) -> 'BackupPolicyPostgresqlFlexibleServer':
        """
        Get an existing BackupPolicyPostgresqlFlexibleServer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] backup_repeating_time_intervals: Specifies a list of repeating time interval. It supports weekly back. It should follow `ISO 8601` repeating time interval format. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerDefaultRetentionRuleArgsDict']] default_retention_rule: A `default_retention_rule` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies the name of the Backup Policy for the PostgreSQL Flexible Server. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[Union['BackupPolicyPostgresqlFlexibleServerRetentionRuleArgs', 'BackupPolicyPostgresqlFlexibleServerRetentionRuleArgsDict']]]] retention_rules: One or more `retention_rule` blocks as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] time_zone: Specifies the Time Zone which should be used by the backup schedule. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] vault_id: The ID of the Backup Vault where the Backup Policy PostgreSQL Flexible Server should exist. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BackupPolicyPostgresqlFlexibleServerState.__new__(_BackupPolicyPostgresqlFlexibleServerState)

        __props__.__dict__["backup_repeating_time_intervals"] = backup_repeating_time_intervals
        __props__.__dict__["default_retention_rule"] = default_retention_rule
        __props__.__dict__["name"] = name
        __props__.__dict__["retention_rules"] = retention_rules
        __props__.__dict__["time_zone"] = time_zone
        __props__.__dict__["vault_id"] = vault_id
        return BackupPolicyPostgresqlFlexibleServer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="backupRepeatingTimeIntervals")
    def backup_repeating_time_intervals(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        Specifies a list of repeating time interval. It supports weekly back. It should follow `ISO 8601` repeating time interval format. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "backup_repeating_time_intervals")

    @property
    @pulumi.getter(name="defaultRetentionRule")
    def default_retention_rule(self) -> pulumi.Output['outputs.BackupPolicyPostgresqlFlexibleServerDefaultRetentionRule']:
        """
        A `default_retention_rule` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "default_retention_rule")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Specifies the name of the Backup Policy for the PostgreSQL Flexible Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="retentionRules")
    def retention_rules(self) -> pulumi.Output[Optional[Sequence['outputs.BackupPolicyPostgresqlFlexibleServerRetentionRule']]]:
        """
        One or more `retention_rule` blocks as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "retention_rules")

    @property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Specifies the Time Zone which should be used by the backup schedule. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "time_zone")

    @property
    @pulumi.getter(name="vaultId")
    def vault_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the Backup Vault where the Backup Policy PostgreSQL Flexible Server should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "vault_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PlacementGroupArgs', 'PlacementGroup']

@pulumi.input_type
class PlacementGroupArgs:
    def __init__(__self__, *,
                 resource_group_name: pulumi.Input[builtins.str],
                 allowed_vm_sizes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a PlacementGroup resource.
        :param pulumi.Input[builtins.str] resource_group_name: The name of the resource group in which to create the availability set. Changing this forces a new resource to be created.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allowed_vm_sizes: Specifies the supported sizes of Virtual Machines that can be created in the Proximity Placement Group.
               
               > **Note:** Removing `allowed_vm_sizes` after it is set forces a new resource to be created.
        :param pulumi.Input[builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies the name of the proximity placement group. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[builtins.str] zone: Specifies the supported zone of the Proximity Placement Group. Changing this forces a new resource to be created.
               
               > **Note:** `allowed_vm_sizes` must be set when `zone` is specified.
        """
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if allowed_vm_sizes is not None:
            pulumi.set(__self__, "allowed_vm_sizes", allowed_vm_sizes)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the resource group in which to create the availability set. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="allowedVmSizes")
    def allowed_vm_sizes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Specifies the supported sizes of Virtual Machines that can be created in the Proximity Placement Group.

        > **Note:** Removing `allowed_vm_sizes` after it is set forces a new resource to be created.
        """
        return pulumi.get(self, "allowed_vm_sizes")

    @allowed_vm_sizes.setter
    def allowed_vm_sizes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allowed_vm_sizes", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the name of the proximity placement group. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the supported zone of the Proximity Placement Group. Changing this forces a new resource to be created.

        > **Note:** `allowed_vm_sizes` must be set when `zone` is specified.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _PlacementGroupState:
    def __init__(__self__, *,
                 allowed_vm_sizes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering PlacementGroup resources.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allowed_vm_sizes: Specifies the supported sizes of Virtual Machines that can be created in the Proximity Placement Group.
               
               > **Note:** Removing `allowed_vm_sizes` after it is set forces a new resource to be created.
        :param pulumi.Input[builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies the name of the proximity placement group. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: The name of the resource group in which to create the availability set. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[builtins.str] zone: Specifies the supported zone of the Proximity Placement Group. Changing this forces a new resource to be created.
               
               > **Note:** `allowed_vm_sizes` must be set when `zone` is specified.
        """
        if allowed_vm_sizes is not None:
            pulumi.set(__self__, "allowed_vm_sizes", allowed_vm_sizes)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @property
    @pulumi.getter(name="allowedVmSizes")
    def allowed_vm_sizes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Specifies the supported sizes of Virtual Machines that can be created in the Proximity Placement Group.

        > **Note:** Removing `allowed_vm_sizes` after it is set forces a new resource to be created.
        """
        return pulumi.get(self, "allowed_vm_sizes")

    @allowed_vm_sizes.setter
    def allowed_vm_sizes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allowed_vm_sizes", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the name of the proximity placement group. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the resource group in which to create the availability set. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies the supported zone of the Proximity Placement Group. Changing this forces a new resource to be created.

        > **Note:** `allowed_vm_sizes` must be set when `zone` is specified.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.type_token("azure:proximity/placementGroup:PlacementGroup")
class PlacementGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_vm_sizes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages a proximity placement group for virtual machines, virtual machine scale sets and availability sets.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_placement_group = azure.proximity.PlacementGroup("example",
            name="exampleProximityPlacementGroup",
            location=example.location,
            resource_group_name=example.name,
            tags={
                "environment": "Production",
            })
        ```

        ## Import

        Proximity Placement Groups can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:proximity/placementGroup:PlacementGroup example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/example-rg/providers/Microsoft.Compute/proximityPlacementGroups/example-ppg
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allowed_vm_sizes: Specifies the supported sizes of Virtual Machines that can be created in the Proximity Placement Group.
               
               > **Note:** Removing `allowed_vm_sizes` after it is set forces a new resource to be created.
        :param pulumi.Input[builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies the name of the proximity placement group. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: The name of the resource group in which to create the availability set. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[builtins.str] zone: Specifies the supported zone of the Proximity Placement Group. Changing this forces a new resource to be created.
               
               > **Note:** `allowed_vm_sizes` must be set when `zone` is specified.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PlacementGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a proximity placement group for virtual machines, virtual machine scale sets and availability sets.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_placement_group = azure.proximity.PlacementGroup("example",
            name="exampleProximityPlacementGroup",
            location=example.location,
            resource_group_name=example.name,
            tags={
                "environment": "Production",
            })
        ```

        ## Import

        Proximity Placement Groups can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:proximity/placementGroup:PlacementGroup example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/example-rg/providers/Microsoft.Compute/proximityPlacementGroups/example-ppg
        ```

        :param str resource_name: The name of the resource.
        :param PlacementGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PlacementGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allowed_vm_sizes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 zone: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PlacementGroupArgs.__new__(PlacementGroupArgs)

            __props__.__dict__["allowed_vm_sizes"] = allowed_vm_sizes
            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["zone"] = zone
        super(PlacementGroup, __self__).__init__(
            'azure:proximity/placementGroup:PlacementGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allowed_vm_sizes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            location: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            zone: Optional[pulumi.Input[builtins.str]] = None) -> 'PlacementGroup':
        """
        Get an existing PlacementGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allowed_vm_sizes: Specifies the supported sizes of Virtual Machines that can be created in the Proximity Placement Group.
               
               > **Note:** Removing `allowed_vm_sizes` after it is set forces a new resource to be created.
        :param pulumi.Input[builtins.str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies the name of the proximity placement group. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: The name of the resource group in which to create the availability set. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[builtins.str] zone: Specifies the supported zone of the Proximity Placement Group. Changing this forces a new resource to be created.
               
               > **Note:** `allowed_vm_sizes` must be set when `zone` is specified.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PlacementGroupState.__new__(_PlacementGroupState)

        __props__.__dict__["allowed_vm_sizes"] = allowed_vm_sizes
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["zone"] = zone
        return PlacementGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowedVmSizes")
    def allowed_vm_sizes(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Specifies the supported sizes of Virtual Machines that can be created in the Proximity Placement Group.

        > **Note:** Removing `allowed_vm_sizes` after it is set forces a new resource to be created.
        """
        return pulumi.get(self, "allowed_vm_sizes")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[builtins.str]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Specifies the name of the proximity placement group. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the resource group in which to create the availability set. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Specifies the supported zone of the Proximity Placement Group. Changing this forces a new resource to be created.

        > **Note:** `allowed_vm_sizes` must be set when `zone` is specified.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VirtualMachineManagerServerArgs', 'VirtualMachineManagerServer']

@pulumi.input_type
class VirtualMachineManagerServerArgs:
    def __init__(__self__, *,
                 custom_location_id: pulumi.Input[builtins.str],
                 fqdn: pulumi.Input[builtins.str],
                 password: pulumi.Input[builtins.str],
                 resource_group_name: pulumi.Input[builtins.str],
                 username: pulumi.Input[builtins.str],
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a VirtualMachineManagerServer resource.
        :param pulumi.Input[builtins.str] custom_location_id: The ID of the Custom Location for the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] fqdn: The FQDN of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] password: The password that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: The name of the Resource Group where the System Center Virtual Machine Manager should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] username: The username that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] location: The Azure Region where the System Center Virtual Machine Manager Server should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: The name of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.int] port: The port on which the System Center Virtual Machine Manager Server is listening. Possible values are between `1` and `65535`. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags which should be assigned to the System Center Virtual Machine Manager Server.
        """
        pulumi.set(__self__, "custom_location_id", custom_location_id)
        pulumi.set(__self__, "fqdn", fqdn)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "username", username)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="customLocationId")
    def custom_location_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the Custom Location for the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "custom_location_id")

    @custom_location_id.setter
    def custom_location_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "custom_location_id", value)

    @property
    @pulumi.getter
    def fqdn(self) -> pulumi.Input[builtins.str]:
        """
        The FQDN of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "fqdn")

    @fqdn.setter
    def fqdn(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "fqdn", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[builtins.str]:
        """
        The password that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the Resource Group where the System Center Virtual Machine Manager should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def username(self) -> pulumi.Input[builtins.str]:
        """
        The username that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Azure Region where the System Center Virtual Machine Manager Server should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The port on which the System Center Virtual Machine Manager Server is listening. Possible values are between `1` and `65535`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the System Center Virtual Machine Manager Server.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _VirtualMachineManagerServerState:
    def __init__(__self__, *,
                 custom_location_id: Optional[pulumi.Input[builtins.str]] = None,
                 fqdn: Optional[pulumi.Input[builtins.str]] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering VirtualMachineManagerServer resources.
        :param pulumi.Input[builtins.str] custom_location_id: The ID of the Custom Location for the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] fqdn: The FQDN of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] location: The Azure Region where the System Center Virtual Machine Manager Server should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: The name of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] password: The password that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.int] port: The port on which the System Center Virtual Machine Manager Server is listening. Possible values are between `1` and `65535`. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: The name of the Resource Group where the System Center Virtual Machine Manager should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags which should be assigned to the System Center Virtual Machine Manager Server.
        :param pulumi.Input[builtins.str] username: The username that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        if custom_location_id is not None:
            pulumi.set(__self__, "custom_location_id", custom_location_id)
        if fqdn is not None:
            pulumi.set(__self__, "fqdn", fqdn)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if username is not None:
            pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="customLocationId")
    def custom_location_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the Custom Location for the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "custom_location_id")

    @custom_location_id.setter
    def custom_location_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "custom_location_id", value)

    @property
    @pulumi.getter
    def fqdn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The FQDN of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "fqdn")

    @fqdn.setter
    def fqdn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "fqdn", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The Azure Region where the System Center Virtual Machine Manager Server should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The password that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The port on which the System Center Virtual Machine Manager Server is listening. Possible values are between `1` and `65535`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the Resource Group where the System Center Virtual Machine Manager should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the System Center Virtual Machine Manager Server.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The username that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)


@pulumi.type_token("azure:systemcenter/virtualMachineManagerServer:VirtualMachineManagerServer")
class VirtualMachineManagerServer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_location_id: Optional[pulumi.Input[builtins.str]] = None,
                 fqdn: Optional[pulumi.Input[builtins.str]] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manages a System Center Virtual Machine Manager Server.

        > **Note:** By request of the service team the provider no longer automatically registering the `Microsoft.ScVmm` Resource Provider for this resource. To register it you can run `az provider register --namespace Microsoft.ScVmm`.

        > **Note:** This resource depends on an existing `System Center Virtual Machine Manager Host Machine`, `Arc Resource Bridge` and `Custom Location`. Installing and configuring these dependencies is outside the scope of this document. See [Virtual Machine Manager documentation](https://learn.microsoft.com/en-us/system-center/vmm/?view=sc-vmm-2022) and [Install VMM](https://learn.microsoft.com/en-us/system-center/vmm/install?view=sc-vmm-2022) for more details of `System Center Virtual Machine Manager Host Machine`. See [What is Azure Arc resource bridge](https://learn.microsoft.com/en-us/azure/azure-arc/resource-bridge/overview) and [Overview of Arc-enabled System Center Virtual Machine Manager](https://learn.microsoft.com/en-us/azure/azure-arc/system-center-virtual-machine-manager/overview) for more details of `Arc Resource Bridge/Appliance`. See [Create and manage custom locations on Azure Arc-enabled Kubernetes](https://learn.microsoft.com/en-us/azure/azure-arc/kubernetes/custom-locations) for more details of `Custom Location`. If you encounter issues while configuring, we'd recommend opening a ticket with Microsoft Support.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_machine_manager_server = azure.systemcenter.VirtualMachineManagerServer("example",
            name="example-scvmmms",
            resource_group_name=example.name,
            location=example.location,
            custom_location_id="/subscriptions/12345678-1234-9876-4563-123456789012/resourceGroups/resGroup1/providers/Microsoft.ExtendedLocation/customLocations/customLocation1",
            fqdn="example.labtest",
            username="testUser",
            password="H@Sh1CoR3!")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.ScVmm`: 2023-10-07

        ## Import

        System Center Virtual Machine Manager Servers can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:systemcenter/virtualMachineManagerServer:VirtualMachineManagerServer example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.ScVmm/vmmServers/vmmServer1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] custom_location_id: The ID of the Custom Location for the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] fqdn: The FQDN of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] location: The Azure Region where the System Center Virtual Machine Manager Server should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: The name of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] password: The password that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.int] port: The port on which the System Center Virtual Machine Manager Server is listening. Possible values are between `1` and `65535`. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: The name of the Resource Group where the System Center Virtual Machine Manager should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags which should be assigned to the System Center Virtual Machine Manager Server.
        :param pulumi.Input[builtins.str] username: The username that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VirtualMachineManagerServerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a System Center Virtual Machine Manager Server.

        > **Note:** By request of the service team the provider no longer automatically registering the `Microsoft.ScVmm` Resource Provider for this resource. To register it you can run `az provider register --namespace Microsoft.ScVmm`.

        > **Note:** This resource depends on an existing `System Center Virtual Machine Manager Host Machine`, `Arc Resource Bridge` and `Custom Location`. Installing and configuring these dependencies is outside the scope of this document. See [Virtual Machine Manager documentation](https://learn.microsoft.com/en-us/system-center/vmm/?view=sc-vmm-2022) and [Install VMM](https://learn.microsoft.com/en-us/system-center/vmm/install?view=sc-vmm-2022) for more details of `System Center Virtual Machine Manager Host Machine`. See [What is Azure Arc resource bridge](https://learn.microsoft.com/en-us/azure/azure-arc/resource-bridge/overview) and [Overview of Arc-enabled System Center Virtual Machine Manager](https://learn.microsoft.com/en-us/azure/azure-arc/system-center-virtual-machine-manager/overview) for more details of `Arc Resource Bridge/Appliance`. See [Create and manage custom locations on Azure Arc-enabled Kubernetes](https://learn.microsoft.com/en-us/azure/azure-arc/kubernetes/custom-locations) for more details of `Custom Location`. If you encounter issues while configuring, we'd recommend opening a ticket with Microsoft Support.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_machine_manager_server = azure.systemcenter.VirtualMachineManagerServer("example",
            name="example-scvmmms",
            resource_group_name=example.name,
            location=example.location,
            custom_location_id="/subscriptions/12345678-1234-9876-4563-123456789012/resourceGroups/resGroup1/providers/Microsoft.ExtendedLocation/customLocations/customLocation1",
            fqdn="example.labtest",
            username="testUser",
            password="H@Sh1CoR3!")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.ScVmm`: 2023-10-07

        ## Import

        System Center Virtual Machine Manager Servers can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:systemcenter/virtualMachineManagerServer:VirtualMachineManagerServer example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resourceGroup1/providers/Microsoft.ScVmm/vmmServers/vmmServer1
        ```

        :param str resource_name: The name of the resource.
        :param VirtualMachineManagerServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VirtualMachineManagerServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_location_id: Optional[pulumi.Input[builtins.str]] = None,
                 fqdn: Optional[pulumi.Input[builtins.str]] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VirtualMachineManagerServerArgs.__new__(VirtualMachineManagerServerArgs)

            if custom_location_id is None and not opts.urn:
                raise TypeError("Missing required property 'custom_location_id'")
            __props__.__dict__["custom_location_id"] = custom_location_id
            if fqdn is None and not opts.urn:
                raise TypeError("Missing required property 'fqdn'")
            __props__.__dict__["fqdn"] = fqdn
            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["port"] = port
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["tags"] = tags
            if username is None and not opts.urn:
                raise TypeError("Missing required property 'username'")
            __props__.__dict__["username"] = username
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(VirtualMachineManagerServer, __self__).__init__(
            'azure:systemcenter/virtualMachineManagerServer:VirtualMachineManagerServer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            custom_location_id: Optional[pulumi.Input[builtins.str]] = None,
            fqdn: Optional[pulumi.Input[builtins.str]] = None,
            location: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            username: Optional[pulumi.Input[builtins.str]] = None) -> 'VirtualMachineManagerServer':
        """
        Get an existing VirtualMachineManagerServer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] custom_location_id: The ID of the Custom Location for the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] fqdn: The FQDN of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] location: The Azure Region where the System Center Virtual Machine Manager Server should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] name: The name of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] password: The password that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.int] port: The port on which the System Center Virtual Machine Manager Server is listening. Possible values are between `1` and `65535`. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: The name of the Resource Group where the System Center Virtual Machine Manager should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags which should be assigned to the System Center Virtual Machine Manager Server.
        :param pulumi.Input[builtins.str] username: The username that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VirtualMachineManagerServerState.__new__(_VirtualMachineManagerServerState)

        __props__.__dict__["custom_location_id"] = custom_location_id
        __props__.__dict__["fqdn"] = fqdn
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["port"] = port
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["username"] = username
        return VirtualMachineManagerServer(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="customLocationId")
    def custom_location_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the Custom Location for the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "custom_location_id")

    @property
    @pulumi.getter
    def fqdn(self) -> pulumi.Output[builtins.str]:
        """
        The FQDN of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "fqdn")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[builtins.str]:
        """
        The Azure Region where the System Center Virtual Machine Manager Server should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        The password that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The port on which the System Center Virtual Machine Manager Server is listening. Possible values are between `1` and `65535`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the Resource Group where the System Center Virtual Machine Manager should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        A mapping of tags which should be assigned to the System Center Virtual Machine Manager Server.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[builtins.str]:
        """
        The username that is used to connect to the System Center Virtual Machine Manager Server. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "username")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetRoleAssignmentsResult',
    'AwaitableGetRoleAssignmentsResult',
    'get_role_assignments',
    'get_role_assignments_output',
]

@pulumi.output_type
class GetRoleAssignmentsResult:
    """
    A collection of values returned by getRoleAssignments.
    """
    def __init__(__self__, id=None, limit_at_scope=None, principal_id=None, role_assignments=None, scope=None, tenant_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if limit_at_scope and not isinstance(limit_at_scope, bool):
            raise TypeError("Expected argument 'limit_at_scope' to be a bool")
        pulumi.set(__self__, "limit_at_scope", limit_at_scope)
        if principal_id and not isinstance(principal_id, str):
            raise TypeError("Expected argument 'principal_id' to be a str")
        pulumi.set(__self__, "principal_id", principal_id)
        if role_assignments and not isinstance(role_assignments, list):
            raise TypeError("Expected argument 'role_assignments' to be a list")
        pulumi.set(__self__, "role_assignments", role_assignments)
        if scope and not isinstance(scope, str):
            raise TypeError("Expected argument 'scope' to be a str")
        pulumi.set(__self__, "scope", scope)
        if tenant_id and not isinstance(tenant_id, str):
            raise TypeError("Expected argument 'tenant_id' to be a str")
        pulumi.set(__self__, "tenant_id", tenant_id)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="limitAtScope")
    def limit_at_scope(self) -> Optional[builtins.bool]:
        return pulumi.get(self, "limit_at_scope")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[builtins.str]:
        """
        The principal ID.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="roleAssignments")
    def role_assignments(self) -> Sequence['outputs.GetRoleAssignmentsRoleAssignmentResult']:
        """
        A `role_assignments` block as defined below.
        """
        return pulumi.get(self, "role_assignments")

    @property
    @pulumi.getter
    def scope(self) -> builtins.str:
        return pulumi.get(self, "scope")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "tenant_id")


class AwaitableGetRoleAssignmentsResult(GetRoleAssignmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRoleAssignmentsResult(
            id=self.id,
            limit_at_scope=self.limit_at_scope,
            principal_id=self.principal_id,
            role_assignments=self.role_assignments,
            scope=self.scope,
            tenant_id=self.tenant_id)


def get_role_assignments(limit_at_scope: Optional[builtins.bool] = None,
                         principal_id: Optional[builtins.str] = None,
                         scope: Optional[builtins.str] = None,
                         tenant_id: Optional[builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRoleAssignmentsResult:
    """
    Use this data source to access information about existing Role Assignments.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_resource_group = azure.core.ResourceGroup("example",
        name="example",
        location="West Europe")
    example = azure.pim.get_role_assignments_output(scope=example_resource_group.id)
    pulumi.export("id", example.role_assignments)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Authorization`: 2022-04-01


    :param builtins.bool limit_at_scope: Whether to limit the result exactly at the specified scope and not above or below it. Defaults to `false`.
    :param builtins.str principal_id: The principal ID to filter the list of Role Assignments against.
    :param builtins.str scope: The scope at which to list Role Assignments.
    :param builtins.str tenant_id: The tenant ID for cross-tenant requests.
    """
    __args__ = dict()
    __args__['limitAtScope'] = limit_at_scope
    __args__['principalId'] = principal_id
    __args__['scope'] = scope
    __args__['tenantId'] = tenant_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:pim/getRoleAssignments:getRoleAssignments', __args__, opts=opts, typ=GetRoleAssignmentsResult).value

    return AwaitableGetRoleAssignmentsResult(
        id=pulumi.get(__ret__, 'id'),
        limit_at_scope=pulumi.get(__ret__, 'limit_at_scope'),
        principal_id=pulumi.get(__ret__, 'principal_id'),
        role_assignments=pulumi.get(__ret__, 'role_assignments'),
        scope=pulumi.get(__ret__, 'scope'),
        tenant_id=pulumi.get(__ret__, 'tenant_id'))
def get_role_assignments_output(limit_at_scope: Optional[pulumi.Input[Optional[builtins.bool]]] = None,
                                principal_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                scope: Optional[pulumi.Input[builtins.str]] = None,
                                tenant_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRoleAssignmentsResult]:
    """
    Use this data source to access information about existing Role Assignments.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_resource_group = azure.core.ResourceGroup("example",
        name="example",
        location="West Europe")
    example = azure.pim.get_role_assignments_output(scope=example_resource_group.id)
    pulumi.export("id", example.role_assignments)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Authorization`: 2022-04-01


    :param builtins.bool limit_at_scope: Whether to limit the result exactly at the specified scope and not above or below it. Defaults to `false`.
    :param builtins.str principal_id: The principal ID to filter the list of Role Assignments against.
    :param builtins.str scope: The scope at which to list Role Assignments.
    :param builtins.str tenant_id: The tenant ID for cross-tenant requests.
    """
    __args__ = dict()
    __args__['limitAtScope'] = limit_at_scope
    __args__['principalId'] = principal_id
    __args__['scope'] = scope
    __args__['tenantId'] = tenant_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:pim/getRoleAssignments:getRoleAssignments', __args__, opts=opts, typ=GetRoleAssignmentsResult)
    return __ret__.apply(lambda __response__: GetRoleAssignmentsResult(
        id=pulumi.get(__response__, 'id'),
        limit_at_scope=pulumi.get(__response__, 'limit_at_scope'),
        principal_id=pulumi.get(__response__, 'principal_id'),
        role_assignments=pulumi.get(__response__, 'role_assignments'),
        scope=pulumi.get(__response__, 'scope'),
        tenant_id=pulumi.get(__response__, 'tenant_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['HealthbotArgs', 'Healthbot']

@pulumi.input_type
class HealthbotArgs:
    def __init__(__self__, *,
                 resource_group_name: pulumi.Input[builtins.str],
                 sku_name: pulumi.Input[builtins.str],
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a Healthbot resource.
        :param pulumi.Input[builtins.str] resource_group_name: Specifies The name of the Resource Group in which to create the Healthbot Service. changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] sku_name: The name which should be used for the SKU of the service. Possible values are `C0`, `F0` and `S1`.
        :param pulumi.Input[builtins.str] location: Specifies The Azure Region where the resource exists. Changing this force a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies The name of the Healthbot Service resource. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags which should be assigned to the service.
        """
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "sku_name", sku_name)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[builtins.str]:
        """
        Specifies The name of the Resource Group in which to create the Healthbot Service. changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> pulumi.Input[builtins.str]:
        """
        The name which should be used for the SKU of the service. Possible values are `C0`, `F0` and `S1`.
        """
        return pulumi.get(self, "sku_name")

    @sku_name.setter
    def sku_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "sku_name", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies The Azure Region where the resource exists. Changing this force a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies The name of the Healthbot Service resource. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the service.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _HealthbotState:
    def __init__(__self__, *,
                 bot_management_portal_url: Optional[pulumi.Input[builtins.str]] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 sku_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Healthbot resources.
        :param pulumi.Input[builtins.str] bot_management_portal_url: The management portal url.
        :param pulumi.Input[builtins.str] location: Specifies The Azure Region where the resource exists. Changing this force a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies The name of the Healthbot Service resource. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: Specifies The name of the Resource Group in which to create the Healthbot Service. changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] sku_name: The name which should be used for the SKU of the service. Possible values are `C0`, `F0` and `S1`.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags which should be assigned to the service.
        """
        if bot_management_portal_url is not None:
            pulumi.set(__self__, "bot_management_portal_url", bot_management_portal_url)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if sku_name is not None:
            pulumi.set(__self__, "sku_name", sku_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="botManagementPortalUrl")
    def bot_management_portal_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The management portal url.
        """
        return pulumi.get(self, "bot_management_portal_url")

    @bot_management_portal_url.setter
    def bot_management_portal_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bot_management_portal_url", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies The Azure Region where the resource exists. Changing this force a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies The name of the Healthbot Service resource. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Specifies The name of the Resource Group in which to create the Healthbot Service. changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name which should be used for the SKU of the service. Possible values are `C0`, `F0` and `S1`.
        """
        return pulumi.get(self, "sku_name")

    @sku_name.setter
    def sku_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sku_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the service.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("azure:bot/healthbot:Healthbot")
class Healthbot(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 sku_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        Manages a Healthbot Service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-healthbot",
            location="West Europe")
        example_healthbot = azure.bot.Healthbot("example",
            name="example-bot",
            resource_group_name=example.name,
            location=example.location,
            sku_name="F0")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.HealthBot`: 2022-08-08

        ## Import

        Healthbot Service can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:bot/healthbot:Healthbot example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.HealthBot/healthBots/bot1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] location: Specifies The Azure Region where the resource exists. Changing this force a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies The name of the Healthbot Service resource. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: Specifies The name of the Resource Group in which to create the Healthbot Service. changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] sku_name: The name which should be used for the SKU of the service. Possible values are `C0`, `F0` and `S1`.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags which should be assigned to the service.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HealthbotArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Healthbot Service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-healthbot",
            location="West Europe")
        example_healthbot = azure.bot.Healthbot("example",
            name="example-bot",
            resource_group_name=example.name,
            location=example.location,
            sku_name="F0")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.HealthBot`: 2022-08-08

        ## Import

        Healthbot Service can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:bot/healthbot:Healthbot example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.HealthBot/healthBots/bot1
        ```

        :param str resource_name: The name of the resource.
        :param HealthbotArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HealthbotArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 location: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                 sku_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HealthbotArgs.__new__(HealthbotArgs)

            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if sku_name is None and not opts.urn:
                raise TypeError("Missing required property 'sku_name'")
            __props__.__dict__["sku_name"] = sku_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["bot_management_portal_url"] = None
        super(Healthbot, __self__).__init__(
            'azure:bot/healthbot:Healthbot',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bot_management_portal_url: Optional[pulumi.Input[builtins.str]] = None,
            location: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
            sku_name: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None) -> 'Healthbot':
        """
        Get an existing Healthbot resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] bot_management_portal_url: The management portal url.
        :param pulumi.Input[builtins.str] location: Specifies The Azure Region where the resource exists. Changing this force a new resource to be created.
        :param pulumi.Input[builtins.str] name: Specifies The name of the Healthbot Service resource. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] resource_group_name: Specifies The name of the Resource Group in which to create the Healthbot Service. changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] sku_name: The name which should be used for the SKU of the service. Possible values are `C0`, `F0` and `S1`.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: A mapping of tags which should be assigned to the service.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HealthbotState.__new__(_HealthbotState)

        __props__.__dict__["bot_management_portal_url"] = bot_management_portal_url
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["sku_name"] = sku_name
        __props__.__dict__["tags"] = tags
        return Healthbot(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="botManagementPortalUrl")
    def bot_management_portal_url(self) -> pulumi.Output[builtins.str]:
        """
        The management portal url.
        """
        return pulumi.get(self, "bot_management_portal_url")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[builtins.str]:
        """
        Specifies The Azure Region where the resource exists. Changing this force a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Specifies The name of the Healthbot Service resource. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[builtins.str]:
        """
        Specifies The name of the Resource Group in which to create the Healthbot Service. changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> pulumi.Output[builtins.str]:
        """
        The name which should be used for the SKU of the service. Possible values are `C0`, `F0` and `S1`.
        """
        return pulumi.get(self, "sku_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        A mapping of tags which should be assigned to the service.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetSoaRecordResult',
    'AwaitableGetSoaRecordResult',
    'get_soa_record',
    'get_soa_record_output',
]

@pulumi.output_type
class GetSoaRecordResult:
    """
    A collection of values returned by getSoaRecord.
    """
    def __init__(__self__, email=None, expire_time=None, fqdn=None, host_name=None, id=None, minimum_ttl=None, name=None, refresh_time=None, resource_group_name=None, retry_time=None, serial_number=None, tags=None, ttl=None, zone_name=None):
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if expire_time and not isinstance(expire_time, int):
            raise TypeError("Expected argument 'expire_time' to be a int")
        pulumi.set(__self__, "expire_time", expire_time)
        if fqdn and not isinstance(fqdn, str):
            raise TypeError("Expected argument 'fqdn' to be a str")
        pulumi.set(__self__, "fqdn", fqdn)
        if host_name and not isinstance(host_name, str):
            raise TypeError("Expected argument 'host_name' to be a str")
        pulumi.set(__self__, "host_name", host_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if minimum_ttl and not isinstance(minimum_ttl, int):
            raise TypeError("Expected argument 'minimum_ttl' to be a int")
        pulumi.set(__self__, "minimum_ttl", minimum_ttl)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if refresh_time and not isinstance(refresh_time, int):
            raise TypeError("Expected argument 'refresh_time' to be a int")
        pulumi.set(__self__, "refresh_time", refresh_time)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if retry_time and not isinstance(retry_time, int):
            raise TypeError("Expected argument 'retry_time' to be a int")
        pulumi.set(__self__, "retry_time", retry_time)
        if serial_number and not isinstance(serial_number, int):
            raise TypeError("Expected argument 'serial_number' to be a int")
        pulumi.set(__self__, "serial_number", serial_number)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if ttl and not isinstance(ttl, int):
            raise TypeError("Expected argument 'ttl' to be a int")
        pulumi.set(__self__, "ttl", ttl)
        if zone_name and not isinstance(zone_name, str):
            raise TypeError("Expected argument 'zone_name' to be a str")
        pulumi.set(__self__, "zone_name", zone_name)

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        The email contact for the SOA record.
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="expireTime")
    def expire_time(self) -> builtins.int:
        """
        The expire time for the SOA record.
        """
        return pulumi.get(self, "expire_time")

    @property
    @pulumi.getter
    def fqdn(self) -> builtins.str:
        """
        The FQDN of the DNS SOA Record.
        """
        return pulumi.get(self, "fqdn")

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> builtins.str:
        """
        The domain name of the authoritative name server for the SOA record.
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="minimumTtl")
    def minimum_ttl(self) -> builtins.int:
        """
        The minimum Time To Live for the SOA record. By convention, it is used to determine the negative caching duration.
        """
        return pulumi.get(self, "minimum_ttl")

    @property
    @pulumi.getter
    def name(self) -> Optional[builtins.str]:
        """
        The name of the DNS SOA Record.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="refreshTime")
    def refresh_time(self) -> builtins.int:
        """
        The refresh time for the SOA record.
        """
        return pulumi.get(self, "refresh_time")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> builtins.str:
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="retryTime")
    def retry_time(self) -> builtins.int:
        """
        The retry time for the SOA record.
        """
        return pulumi.get(self, "retry_time")

    @property
    @pulumi.getter(name="serialNumber")
    def serial_number(self) -> builtins.int:
        """
        The serial number for the SOA record.
        """
        return pulumi.get(self, "serial_number")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        A mapping of tags assigned to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def ttl(self) -> builtins.int:
        """
        The Time To Live (TTL) of the DNS record in seconds.
        """
        return pulumi.get(self, "ttl")

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> builtins.str:
        return pulumi.get(self, "zone_name")


class AwaitableGetSoaRecordResult(GetSoaRecordResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSoaRecordResult(
            email=self.email,
            expire_time=self.expire_time,
            fqdn=self.fqdn,
            host_name=self.host_name,
            id=self.id,
            minimum_ttl=self.minimum_ttl,
            name=self.name,
            refresh_time=self.refresh_time,
            resource_group_name=self.resource_group_name,
            retry_time=self.retry_time,
            serial_number=self.serial_number,
            tags=self.tags,
            ttl=self.ttl,
            zone_name=self.zone_name)


def get_soa_record(name: Optional[builtins.str] = None,
                   resource_group_name: Optional[builtins.str] = None,
                   zone_name: Optional[builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSoaRecordResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.dns.get_soa_record(zone_name="test-zone",
        resource_group_name="test-rg")
    pulumi.export("dnsSoaRecordId", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Network`: 2018-05-01


    :param builtins.str name: The name of the DNS SOA Record.
    :param builtins.str resource_group_name: Specifies the resource group where the DNS Zone (parent resource) exists.
    :param builtins.str zone_name: Specifies the DNS Zone where the resource exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['zoneName'] = zone_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:dns/getSoaRecord:getSoaRecord', __args__, opts=opts, typ=GetSoaRecordResult).value

    return AwaitableGetSoaRecordResult(
        email=pulumi.get(__ret__, 'email'),
        expire_time=pulumi.get(__ret__, 'expire_time'),
        fqdn=pulumi.get(__ret__, 'fqdn'),
        host_name=pulumi.get(__ret__, 'host_name'),
        id=pulumi.get(__ret__, 'id'),
        minimum_ttl=pulumi.get(__ret__, 'minimum_ttl'),
        name=pulumi.get(__ret__, 'name'),
        refresh_time=pulumi.get(__ret__, 'refresh_time'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        retry_time=pulumi.get(__ret__, 'retry_time'),
        serial_number=pulumi.get(__ret__, 'serial_number'),
        tags=pulumi.get(__ret__, 'tags'),
        ttl=pulumi.get(__ret__, 'ttl'),
        zone_name=pulumi.get(__ret__, 'zone_name'))
def get_soa_record_output(name: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                          resource_group_name: Optional[pulumi.Input[builtins.str]] = None,
                          zone_name: Optional[pulumi.Input[builtins.str]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSoaRecordResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.dns.get_soa_record(zone_name="test-zone",
        resource_group_name="test-rg")
    pulumi.export("dnsSoaRecordId", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Network`: 2018-05-01


    :param builtins.str name: The name of the DNS SOA Record.
    :param builtins.str resource_group_name: Specifies the resource group where the DNS Zone (parent resource) exists.
    :param builtins.str zone_name: Specifies the DNS Zone where the resource exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['zoneName'] = zone_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:dns/getSoaRecord:getSoaRecord', __args__, opts=opts, typ=GetSoaRecordResult)
    return __ret__.apply(lambda __response__: GetSoaRecordResult(
        email=pulumi.get(__response__, 'email'),
        expire_time=pulumi.get(__response__, 'expire_time'),
        fqdn=pulumi.get(__response__, 'fqdn'),
        host_name=pulumi.get(__response__, 'host_name'),
        id=pulumi.get(__response__, 'id'),
        minimum_ttl=pulumi.get(__response__, 'minimum_ttl'),
        name=pulumi.get(__response__, 'name'),
        refresh_time=pulumi.get(__response__, 'refresh_time'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        retry_time=pulumi.get(__response__, 'retry_time'),
        serial_number=pulumi.get(__response__, 'serial_number'),
        tags=pulumi.get(__response__, 'tags'),
        ttl=pulumi.get(__response__, 'ttl'),
        zone_name=pulumi.get(__response__, 'zone_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .hybrid_connection import *
from .hybrid_connection_authorization_rule import *
from .namespace import *
from .namespace_authorization_rule import *
